pub struct FileSystemSandboxPolicy {
pub kind: FileSystemSandboxKind,
pub entries: Vec<FileSystemSandboxEntry>,
}Fields
kind: FileSystemSandboxKindentries: Vec<FileSystemSandboxEntry>Implementations
Sourceimpl FileSystemSandboxPolicy
impl FileSystemSandboxPolicy
pub fn unrestricted() -> Self
pub fn external_sandbox() -> Self
pub fn restricted(entries: Vec<FileSystemSandboxEntry>) -> Self
Sourcepub fn from_legacy_sandbox_policy(
sandbox_policy: &SandboxPolicy,
cwd: &Path,
) -> Self
pub fn from_legacy_sandbox_policy( sandbox_policy: &SandboxPolicy, cwd: &Path, ) -> Self
Converts a legacy sandbox policy into an equivalent filesystem policy for the provided cwd.
Legacy WorkspaceWrite policies may list readable roots that live
under an already-writable root. Those paths were redundant in the
legacy model and should not become read-only carveouts when projected
into split filesystem policy.
Sourcepub fn has_full_disk_read_access(&self) -> bool
pub fn has_full_disk_read_access(&self) -> bool
Returns true when filesystem reads are unrestricted.
Sourcepub fn has_full_disk_write_access(&self) -> bool
pub fn has_full_disk_write_access(&self) -> bool
Returns true when filesystem writes are unrestricted.
Sourcepub fn include_platform_defaults(&self) -> bool
pub fn include_platform_defaults(&self) -> bool
Returns true when platform-default readable roots should be included.
pub fn resolve_access_with_cwd( &self, path: &Path, cwd: &Path, ) -> FileSystemAccessMode
pub fn can_read_path_with_cwd(&self, path: &Path, cwd: &Path) -> bool
pub fn can_write_path_with_cwd(&self, path: &Path, cwd: &Path) -> bool
pub fn with_additional_readable_roots( self, cwd: &Path, additional_readable_roots: &[AbsolutePathBuf], ) -> Self
pub fn with_additional_writable_roots( self, cwd: &Path, additional_writable_roots: &[AbsolutePathBuf], ) -> Self
pub fn needs_direct_runtime_enforcement( &self, network_policy: NetworkSandboxPolicy, cwd: &Path, ) -> bool
Sourcepub fn get_readable_roots_with_cwd(&self, cwd: &Path) -> Vec<AbsolutePathBuf>
pub fn get_readable_roots_with_cwd(&self, cwd: &Path) -> Vec<AbsolutePathBuf>
Returns the explicit readable roots resolved against the provided cwd.
Sourcepub fn get_writable_roots_with_cwd(&self, cwd: &Path) -> Vec<WritableRoot>
pub fn get_writable_roots_with_cwd(&self, cwd: &Path) -> Vec<WritableRoot>
Returns the writable roots together with read-only carveouts resolved against the provided cwd.
Sourcepub fn get_unreadable_roots_with_cwd(&self, cwd: &Path) -> Vec<AbsolutePathBuf>
pub fn get_unreadable_roots_with_cwd(&self, cwd: &Path) -> Vec<AbsolutePathBuf>
Returns explicit unreadable roots resolved against the provided cwd.
pub fn to_legacy_sandbox_policy( &self, network_policy: NetworkSandboxPolicy, cwd: &Path, ) -> Result<SandboxPolicy>